package com.haoshuo.trackingio

import android.app.Application
import android.content.Context
import androidx.annotation.NonNull
import com.reyun.tracking.sdk.Tracking

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** TrackingioPlugin */
class TrackingioPlugin : FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel

    private lateinit var application: Context

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "com.haoshuo/trackingio")
        channel.setMethodCallHandler(this)

        application = flutterPluginBinding.applicationContext
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {

        if (call.method == "setDebugMode") {
            Tracking.setDebugMode(call.argument<Boolean>("debugMode")!!)
            result.success(null)
        } else if (call.method == "init") {
            var appKey = call.argument<String>("appKey")
            var channel = call.argument<String>("channel")
            Tracking.initWithKeyAndChannelId(
                application.applicationContext as Application,
                appKey,
                channel
            )
            result.success(null)
        } else if (call.method == "setLoginSuccess") {
            var accountId = call.argument<String>("accountId")
            Tracking.setLoginSuccessBusiness(accountId)
            result.success(null)
        } else if (call.method == "setPayment") {
            var transactionId = call.argument<String>("transactionId")!!
            var paymentType = call.argument<String>("paymentType")!!
            var currencyType = call.argument<String>("currencyType")!!
            var currencyAmount = call.argument<Float>("currencyAmount")!!
            Tracking.setPayment(transactionId, paymentType, currencyType, currencyAmount)
            result.success(null)
        } else if (call.method == "event") {
            var eventName = call.argument<String?>("name")
            var data = call.argument<Map<String, Any>?>("data")
            Tracking.setEvent(eventName, data)
            result.success(null)
        } else if (call.method == "register") {
            var accountId = call.argument<String>("accountId")
            Tracking.setRegisterWithAccountID(accountId)
        } else {
            result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }
}
