#import "TrackingioPlugin.h"
#import "trackingio/Tracking.h"

@implementation TrackingioPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"com.haoshuo/trackingio"
            binaryMessenger:[registrar messenger]];
  TrackingioPlugin* instance = [[TrackingioPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSDictionary* arguments = (NSDictionary *)call.arguments;

  if ([@"setDebugMode" isEqualToString:call.method]) {
      bool debugMode = [[arguments objectForKey:@"debugMode"] boolValue];
      [self setDebugMode:debugMode];
      result(@(YES));
  }else if ([@"init" isEqualToString:call.method]) {
      NSString *appKey = [arguments objectForKey:@"appKey"];
      NSString *channel = [arguments objectForKey:@"channel"];
      [self initWithAppKey:appKey channel:channel];
      result(@(YES));
  }else if ([@"setLoginSuccess" isEqualToString:call.method]) {
      NSString *accountId = [arguments objectForKey:@"accountId"];
      [self loginSuccess:accountId];
      result(@(YES));
  }else if ([@"setPayment" isEqualToString:call.method]) {
      NSString *transactionId = [arguments objectForKey:@"transactionId"];
      NSString *paymentType = [arguments objectForKey:@"paymentType"];
      NSString *currencyType = [arguments objectForKey:@"currencyType"];
      double currencyAmount = [[arguments objectForKey:@"currencyAmount"] doubleValue];
      [self setPaymentWithId:transactionId paymentType:paymentType currencyType:currencyType currencyAmount:currencyAmount];
      result(@(YES));
  } else if ([@"event" isEqualToString:call.method]) {
      NSString* event = [arguments objectForKey:@"name"];
      NSDictionary * data = [arguments objectForKey:@"data"];
      [self eventWithName:event data:data];
      result(@(YES));
  } else if ([@"register" isEqualToString:call.method]) {
      NSString *accountId = [arguments objectForKey:@"accountId"];
      [self register:accountId];
      result(@(YES));
  } else {
    result(FlutterMethodNotImplemented);
  }
}

- (void)setDebugMode:(BOOL)debugMode {
    [Tracking setPrintLog:debugMode];
}

- (void)initWithAppKey:(NSString *)appKey channel:(NSString *)channel {
    [Tracking initWithAppKey:appKey withChannelId:channel];
}

- (void)loginSuccess:(NSString *)accountId {
    [Tracking setLoginWithAccountID:accountId];
}

- (void)register:(NSString *)accountId {
    [Tracking setRegisterWithAccountID:accountId];
}

- (void) eventWithName:(NSString*) name data:(NSDictionary*) data {
    [Tracking setEvent:name param:data];
}


- (void)setPaymentWithId:(NSString *)transactionId paymentType:(NSString *)paymentType currencyType:(NSString *)
currencyType currencyAmount:(double)currencyAmount {
    [Tracking setRyzf:transactionId ryzfType:paymentType hbType:currencyType hbAmount:currencyAmount];
}


@end
